pub struct GridCellRect {
pub start_row: usize,
pub start_col: usize,
pub row_span: usize,
pub col_span: usize,
pub content: String,
}Expand description
One laid-out cell of a grid table over the canonical (row band × fine
column) grid. content is the cell’s interior text with one leading pad
space stripped per line, trailing whitespace trimmed, and leading/trailing
blank lines dropped, joined with \n.
Fields
start_row: usizestart_col: usizerow_span: usizecol_span: usizecontent: StringTrait Implementations
Sourceimpl Clone for GridCellRect
impl Clone for GridCellRect
Sourcefn clone(&self) -> GridCellRect
fn clone(&self) -> GridCellRect
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for GridCellRect
impl RefUnwindSafe for GridCellRect
impl Send for GridCellRect
impl Sync for GridCellRect
impl Unpin for GridCellRect
impl UnsafeUnpin for GridCellRect
impl UnwindSafe for GridCellRect