Module figures

Module figures 

Figure parsing for standalone images.

In Pandoc, a paragraph containing only an image (and optional attributes) is treated as a Figure block element rather than a paragraph with inline image.