Module horizontal_rules
panache_
parser
0.17.2
Module horizontal_
rules
Module Items
Functions
In panache_
parser::
parser::
blocks
panache_parser
::
parser
::
blocks
Module
horizontal_
rules
Horizontal rule parsing utilities.
Functions

try_
parse_
horizontal_
rule
Try to parse a horizontal rule from a line. Returns true if this line is a valid horizontal rule.