try_parse_horizontal_rule

Function try_parse_horizontal_rule 

pub fn try_parse_horizontal_rule(line: &str) -> Option<char>
Try to parse a horizontal rule from a line. Returns true if this line is a valid horizontal rule.

A horizontal rule is 3 or more *, -, or _ characters, optionally separated by spaces.