Module line_blocks

Module line_blocks 

Functions

parse_line_block
Parse a complete line block starting at current position. Returns the new position after the line block.
try_parse_line_block_start
Try to parse the start of a line block. Returns Some(()) if this line starts a line block (| followed by space or end of line).