pub struct SyntaxError {
pub range: TextRange,
pub message: String,
pub source: SyntaxErrorSource,
}Expand description
A syntax error the parser found in an embedded sublanguage, with a host-aligned byte range (ready to turn into a diagnostic without any offset remapping).
Fields
range: TextRangemessage: Stringsource: SyntaxErrorSourceTrait Implementations
Sourceimpl Clone for SyntaxError
impl Clone for SyntaxError
Sourcefn clone(&self) -> SyntaxError
fn clone(&self) -> SyntaxError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyntaxError
impl Debug for SyntaxError
impl Eq for SyntaxError
Sourceimpl PartialEq for SyntaxError
impl PartialEq for SyntaxError
Sourcefn eq(&self, other: &SyntaxError) -> bool
fn eq(&self, other: &SyntaxError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SyntaxError