parse_with_refdefs_and_errors

Function parse_with_refdefs_and_errors 

pub fn parse_with_refdefs_and_errors(
    input: &str,
    options: Option<ParserOptions>,
    refdefs: RefdefMap,
) -> (SyntaxNode, Vec<SyntaxError>)
Like parse_with_refdefs, but also returns embedded-sublanguage syntax errors (see parse_with_errors). Used by the salsa parse query, which caches the tree and the errors together from a single parse.