DelimMatch

Struct DelimMatch 

pub struct DelimMatch {
    pub offset_in_run: u8,
    pub len: u8,
    pub is_opener: bool,
    pub partner_event: u32,
    pub partner_offset: u8,
    pub kind: EmphasisKind,
}
One matched fragment within a IrEvent::DelimRun.

Fields

offset_in_run: u8

Byte offset of this fragment relative to the run’s start.

len: u8

Number of bytes in this fragment (1 or 2).

is_opener: bool

Whether this fragment is the opener (true) or closer of the pair.

partner_event: u32

IR event index of the partner run.

partner_offset: u8

Byte offset within the partner run of the partner fragment.

kind: EmphasisKind

Emphasis kind (Emph for len == 1, Strong for len == 2).