pub fn emit_display_math(
builder: &mut GreenNodeBuilder<'_>,
content: &str,
dollar_count: usize,
)Expand description
Emit a display math node to the builder (when occurring inline in paragraph).
pub fn emit_display_math(
builder: &mut GreenNodeBuilder<'_>,
content: &str,
dollar_count: usize,
)Emit a display math node to the builder (when occurring inline in paragraph).