Module raw_inline

Module raw_inline 

Parsing for inline raw spans (content{=format})

Raw inline spans allow embedding raw content for specific output formats. Syntax: content{=format} Examples:

  • <a>html</a>{=html}
  • \LaTeX{=latex}
  • <w:br/>{=openxml}

This is enabled by the raw_attribute extension.

Functions

emit_raw_inline
Emit a raw inline span node to the builder.
is_raw_inline
Check if a code span with attributes is actually a raw inline span. Raw inline spans have attributes of the form {=format} (no other attributes).