pub fn is_raw_inline(attributes: &AttributeBlock) -> Option<&str>Expand description
Check if a code span with attributes is actually a raw inline span. Raw inline spans have attributes of the form {=format} (no other attributes).
pub fn is_raw_inline(attributes: &AttributeBlock) -> Option<&str>Check if a code span with attributes is actually a raw inline span. Raw inline spans have attributes of the form {=format} (no other attributes).