pub struct MathDiagnostic {
pub code: &'static str,
pub message: &'static str,
pub byte_start: usize,
pub byte_end: usize,
}Expand description
A non-fatal problem found while parsing math content. Byte offsets are relative to the math content string (the caller offsets them into host document coordinates when surfacing through the linter/LSP).
Fields
code: &'static strmessage: &'static strbyte_start: usizebyte_end: usizeTrait Implementations
Sourceimpl Clone for MathDiagnostic
impl Clone for MathDiagnostic
Sourcefn clone(&self) -> MathDiagnostic
fn clone(&self) -> MathDiagnostic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MathDiagnostic
impl Debug for MathDiagnostic
impl Eq for MathDiagnostic
Sourceimpl PartialEq for MathDiagnostic
impl PartialEq for MathDiagnostic
Sourcefn eq(&self, other: &MathDiagnostic) -> bool
fn eq(&self, other: &MathDiagnostic) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MathDiagnostic