pub fn try_parse_trailing_attributes(
text: &str,
) -> Option<(AttributeBlock, &str)>Expand description
Try to parse an attribute block from the end of a string Returns: (attribute_block, text_before_attributes)
pub fn try_parse_trailing_attributes(
text: &str,
) -> Option<(AttributeBlock, &str)>Try to parse an attribute block from the end of a string Returns: (attribute_block, text_before_attributes)