parse_stream

Function parse_stream 

pub fn parse_stream(input: &str) -> SyntaxNode
Drive the scanner over input and build a CST. Always returns a SyntaxNode — the scanner is permissive and the builder preserves bytes regardless of well-formedness.