pub fn parse_v2(input: &str) -> SyntaxNodeExpand description
Drive the scanner over input and build a CST. Always returns a
SyntaxNode — the scanner is permissive and the v2 builder
preserves bytes regardless of well-formedness.
pub fn parse_v2(input: &str) -> SyntaxNodeDrive the scanner over input and build a CST. Always returns a
SyntaxNode — the scanner is permissive and the v2 builder
preserves bytes regardless of well-formedness.