pub struct Extensions {Show 68 fields
pub blank_before_header: bool,
pub header_attributes: bool,
pub auto_identifiers: bool,
pub gfm_auto_identifiers: bool,
pub implicit_header_references: bool,
pub blank_before_blockquote: bool,
pub fancy_lists: bool,
pub startnum: bool,
pub example_lists: bool,
pub task_lists: bool,
pub definition_lists: bool,
pub lists_without_preceding_blankline: bool,
pub backtick_code_blocks: bool,
pub fenced_code_blocks: bool,
pub fenced_code_attributes: bool,
pub executable_code: bool,
pub rmarkdown_inline_code: bool,
pub quarto_inline_code: bool,
pub inline_code_attributes: bool,
pub simple_tables: bool,
pub multiline_tables: bool,
pub grid_tables: bool,
pub pipe_tables: bool,
pub table_captions: bool,
pub fenced_divs: bool,
pub native_divs: bool,
pub line_blocks: bool,
pub intraword_underscores: bool,
pub strikeout: bool,
pub superscript: bool,
pub subscript: bool,
pub inline_links: bool,
pub reference_links: bool,
pub shortcut_reference_links: bool,
pub link_attributes: bool,
pub autolinks: bool,
pub inline_images: bool,
pub implicit_figures: bool,
pub tex_math_dollars: bool,
pub tex_math_gfm: bool,
pub tex_math_single_backslash: bool,
pub tex_math_double_backslash: bool,
pub inline_footnotes: bool,
pub footnotes: bool,
pub citations: bool,
pub bracketed_spans: bool,
pub native_spans: bool,
pub yaml_metadata_block: bool,
pub pandoc_title_block: bool,
pub mmd_title_block: bool,
pub raw_html: bool,
pub markdown_in_html_blocks: bool,
pub raw_tex: bool,
pub raw_attribute: bool,
pub all_symbols_escapable: bool,
pub escaped_line_breaks: bool,
pub autolink_bare_uris: bool,
pub hard_line_breaks: bool,
pub mmd_header_identifiers: bool,
pub mmd_link_attributes: bool,
pub alerts: bool,
pub emoji: bool,
pub mark: bool,
pub quarto_callouts: bool,
pub quarto_crossrefs: bool,
pub quarto_shortcodes: bool,
pub bookdown_references: bool,
pub bookdown_equation_references: bool,
}Expand description
Pandoc/Markdown extensions configuration. Each field represents a specific Pandoc extension. Extensions marked with a comment indicate implementation status.
Fields
blank_before_header: boolRequire blank line before headers (default: enabled)
header_attributes: boolFull attribute syntax on headers {#id .class key=value}
auto_identifiers: boolAuto-generate identifiers from headings
gfm_auto_identifiers: boolUse GitHub’s algorithm for auto-generated heading identifiers
implicit_header_references: boolImplicit header references ([Heading] links to header)
blank_before_blockquote: boolRequire blank line before blockquotes (default: enabled)
fancy_lists: boolFancy list markers (roman numerals, letters, etc.)
startnum: boolStart ordered lists at arbitrary numbers
example_lists: boolExample lists with (@) markers
task_lists: boolGitHub-style task lists - [ ] and - [x]
definition_lists: boolTerm/definition syntax
lists_without_preceding_blankline: boolAllow lists without a preceding blank line
backtick_code_blocks: boolFenced code blocks with backticks
fenced_code_blocks: boolFenced code blocks with tildes
fenced_code_attributes: boolAttributes on fenced code blocks {.language #id}
executable_code: boolExecutable code syntax (currently fenced chunks like {r} / {python})
rmarkdown_inline_code: boolR Markdown inline executable code (...r …)
quarto_inline_code: boolQuarto inline executable code (...{r} …)
inline_code_attributes: boolAttributes on inline code
simple_tables: boolSimple table syntax
multiline_tables: boolMultiline cell content in tables
grid_tables: boolGrid-style tables
pipe_tables: boolPipe tables (GitHub/PHP Markdown style)
table_captions: boolTable captions
fenced_divs: boolFenced divs ::: {.class}
native_divs: boolHTML
line_blocks: boolLine blocks for poetry | prefix
intraword_underscores: boolUnderscores don’t trigger emphasis in snake_case
strikeout: boolStrikethrough text
superscript: boolSuperscript and subscript ^super^ sub
subscript: boolinline_links: boolInline links text
reference_links: boolReference links [text][ref]
shortcut_reference_links: boolShortcut reference links [ref] without second []
link_attributes: boolAttributes on links text{.class}
autolinks: boolAutomatic links http://example.com
inline_images: boolInline images
implicit_figures: boolParagraph with just image becomes figure
tex_math_dollars: boolDollar-delimited math $x$ and $$equation$$
tex_math_gfm: bool[NON-DEFAULT] GFM math: inline $...$ and fenced ``` math blocks
tex_math_single_backslash: bool[NON-DEFAULT] Single backslash math (…) and […] (RMarkdown default)
tex_math_double_backslash: bool[NON-DEFAULT] Double backslash math \(…\) and \[…\]
inline_footnotes: boolInline footnotes ^[text]
footnotes: boolReference footnotes [^1] (requires footnote parsing)
citations: boolCitation syntax [@cite]
bracketed_spans: boolBracketed spans [text]{.class}
native_spans: boolHTML elements
yaml_metadata_block: boolYAML metadata block
pandoc_title_block: boolPandoc title block (Title/Author/Date)
mmd_title_block: bool[NON-DEFAULT] MultiMarkdown metadata/title block (Key: Value …)
raw_html: boolRaw HTML blocks and inline
markdown_in_html_blocks: boolMarkdown inside HTML blocks
raw_tex: boolLaTeX commands and environments
raw_attribute: boolGeneric raw blocks with {=format} syntax
all_symbols_escapable: boolBackslash escapes any symbol
escaped_line_breaks: boolBackslash at line end = hard line break
autolink_bare_uris: bool[NON-DEFAULT] Bare URLs become links
hard_line_breaks: bool[NON-DEFAULT] Newline =
mmd_header_identifiers: bool[NON-DEFAULT] MultiMarkdown style heading identifiers [my-id]
mmd_link_attributes: bool[NON-DEFAULT] MultiMarkdown key=value attributes on reference defs
alerts: bool[NON-DEFAULT] GitHub/CommonMark alerts in blockquotes (> [!NOTE])
emoji: bool[NON-DEFAULT] :emoji: syntax
mark: bool[NON-DEFAULT] Highlighted ==text==
quarto_callouts: boolQuarto callout blocks (.callout-note, etc.)
quarto_crossrefs: boolQuarto cross-references @fig-id, @tbl-id
quarto_shortcodes: boolQuarto shortcodes {{< name args >}}
bookdown_references: boolBookdown references @ref(label) and (#label)
bookdown_equation_references: boolBookdown equation references in LaTeX math blocks (#eq:label)
Implementations
Sourceimpl Extensions
impl Extensions
Sourcepub fn for_flavor(flavor: Flavor) -> Self
pub fn for_flavor(flavor: Flavor) -> Self
Get the default extension set for a given flavor.
Sourcepub fn merge_with_flavor(
user_overrides: HashMap<String, bool>,
flavor: Flavor,
) -> Self
pub fn merge_with_flavor( user_overrides: HashMap<String, bool>, flavor: Flavor, ) -> Self
Merge user-specified extension overrides with flavor defaults.
This is used to support partial extension overrides in config files.
For example, if a user specifies flavor = "quarto" and then sets
[extensions] quarto-crossrefs = false, we want all other extensions
to use Quarto defaults, not Pandoc defaults.
Arguments
user_overrides- Map of extension names to their user-specified valuesflavor- The flavor to use for default values
Returns
A new Extensions struct with flavor defaults merged with user overrides