Module ast

Module ast 

AST node trait and support utilities.

Structs

AstChildren

Traits

AstNode
The main trait to go from untyped SyntaxNode to a typed AST. The conversion itself has zero runtime cost: AST and syntax nodes have exactly the same representation: a pointer to the tree root and a pointer to the node itself.