pub struct BlockQuote(/* private fields */);Implementations
Sourceimpl BlockQuote
impl BlockQuote
Sourcepub fn blocks(&self) -> impl Iterator<Item = SyntaxNode>
pub fn blocks(&self) -> impl Iterator<Item = SyntaxNode>
Returns block-level children inside this block quote.
Sourcepub fn nested_blockquotes(&self) -> AstChildren<BlockQuote> ⓘ
pub fn nested_blockquotes(&self) -> AstChildren<BlockQuote> ⓘ
Returns nested block quotes directly inside this block quote.
Sourcepub fn contains_node(node: &SyntaxNode) -> bool
pub fn contains_node(node: &SyntaxNode) -> bool
Returns true if the given node is inside any block quote.