pub struct ReferenceDefinition(/* private fields */);Implementations
Sourceimpl ReferenceDefinition
impl ReferenceDefinition
Sourcepub fn destination(&self) -> Option<String>
pub fn destination(&self) -> Option<String>
Extracts raw destination text from a reference definition body.
Sourcepub fn label_value_range(&self) -> Option<TextRange>
pub fn label_value_range(&self) -> Option<TextRange>
Returns the text range for the definition label value.