Indented code block parsing utilities.
A block of text indented four spaces (or one tab) is treated as verbatim text. The initial (four space or one tab) indentation is not considered part of the verbatim text and is removed in the output.
Note: blank lines in the verbatim text need not begin with four spaces.