find_incremental_restart_offset

Function find_incremental_restart_offset 

pub fn find_incremental_restart_offset(
    tree: &SyntaxNode,
    start: usize,
    end: usize,
) -> usize
Find a conservative restart offset for incremental reparsing.

This uses block expansion and then widens to include the previous sibling block, which helps preserve continuation-sensitive parser context.