Module syntax

Module syntax 

Syntax tree types and AST node wrappers for Quarto/Pandoc documents.

This module provides a typed API over the raw concrete syntax tree (CST) produced by the parser. The CST is based on the rowan library and uses the red-green tree pattern for efficient incremental parsing.

Re-exports

pub use alerts::*;
pub use ast::*;
pub use attributes::*;
pub use block_quotes::*;
pub use blocks::*;
pub use chunk_options::*;
pub use citations::*;
pub use code_blocks::*;
pub use crossrefs::*;
pub use definitions::*;
pub use fenced_divs::*;
pub use headings::*;
pub use inlines::*;
pub use json::*;
pub use kind::*;
pub use links::*;
pub use lists::*;
pub use math::*;
pub use raw_tex::*;
pub use references::*;
pub use shortcodes::*;
pub use tables::*;
pub use yaml::*;

Modules

alerts
Alert block AST node wrappers.
ast
AST node trait and support utilities.
attributes
block_quotes
Block quote AST node wrappers.
blocks
chunk_options
Chunk option AST wrappers for type-safe access to chunk options in executable code blocks.
citations
Citation AST node wrappers.
code_blocks
Code block and chunk AST node wrappers.
crossrefs
Cross-reference AST node wrappers.
definitions
Definition list AST node wrappers.
fenced_divs
Fenced div AST node wrappers.
headings
Heading AST node wrappers.
inlines
Inline AST node wrappers.
json
kind
Syntax kinds and language definition for the Quarto/Pandoc CST.
links
Link and image AST node wrappers.
lists
List AST node wrappers.
math
Math AST node wrappers.
raw_tex
Raw TeX AST node wrappers.
references
Reference link and footnote AST node wrappers.
shortcodes
Quarto shortcode AST node wrappers.
tables
Table AST node wrappers.
yaml

Type Aliases

SyntaxElement
SyntaxNode
SyntaxToken