Chunk option AST wrappers for type-safe access to chunk options in executable code blocks.
Structs
- Chunk
Class - A class attribute in an executable code block (e.g.,
.marimoin{python .marimo}). The text accessor includes the leading.. - ChunkId
- An id attribute in an executable code block (e.g.,
#setupin{r #setup}). The text accessor includes the leading#. - Chunk
Label - A chunk label in an executable code block (e.g.,
mylabelin{r mylabel}). - Chunk
Label Entry - Chunk
Option - A chunk option in an executable code block (e.g.,
echo=TRUEorfig.cap="text"). - Chunk
Option Entry - Chunk
Options