Module chunk_options

Module chunk_options 

Chunk option AST wrappers for type-safe access to chunk options in executable code blocks.

Structs

ChunkLabel
A chunk label in an executable code block (e.g., mylabel in {r mylabel}).
ChunkLabelEntry
ChunkOption
A chunk option in an executable code block (e.g., echo=TRUE or fig.cap="text").
ChunkOptionEntry
ChunkOptions

Enums

ChunkInfoItem
ChunkLabelSource
ChunkOptionSource

Functions

collect_option_entries_from_descendants