pub struct ChunkOption(/* private fields */);Expand description
A chunk option in an executable code block (e.g., echo=TRUE or fig.cap="text").
Implementations
Sourceimpl ChunkOption
impl ChunkOption
Sourcepub fn value(&self) -> Option<String>
pub fn value(&self) -> Option<String>
Get the option value (e.g., “TRUE”, “A nice plot”). Returns None for options without values.
Sourcepub fn value_range(&self) -> Option<TextRange>
pub fn value_range(&self) -> Option<TextRange>
Get the value token range, if present.
Sourcepub fn quote_char(&self) -> Option<char>
pub fn quote_char(&self) -> Option<char>
Get the quote character if the value is quoted.